'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var Fade = _interopDefault(require('@material-ui/core/Fade'));
var colorManipulator = require('@material-ui/core/styles/colorManipulator');
var makeStyles = _interopDefault(require('@material-ui/core/styles/makeStyles'));
var CloseIcon = _interopDefault(require('@material-ui/icons/Close'));
var clsx = _interopDefault(require('clsx'));
var React = _interopDefault(require('react'));
var styles = require('@material-ui/core/styles');
var MUITypography = _interopDefault(require('@material-ui/core/Typography'));
var MUIButton = _interopDefault(require('@material-ui/core/Button'));
var MUICard = _interopDefault(require('@material-ui/core/Card'));
var CardActionArea = _interopDefault(require('@material-ui/core/CardActionArea'));
var CardActions = _interopDefault(require('@material-ui/core/CardActions'));
var CardContent = _interopDefault(require('@material-ui/core/CardContent'));
var CardMedia = _interopDefault(require('@material-ui/core/CardMedia'));

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var useStyles = /*#__PURE__*/styles.makeStyles(function (theme) {
  var bootstrapColors = {
    primary: {
      color: theme.palette.primary.main
    },
    secondary: {
      color: theme.palette.secondary.main
    },
    success: {
      color: "#218838"
    },
    danger: {
      color: "#c82333"
    },
    warning: {
      color: "#e0a800"
    },
    info: {
      color: "#138496"
    },
    light: {
      color: theme.palette.text.secondary
    },
    dark: {
      color: theme.palette.text.primary
    }
  };

  function getColor(x) {
    return x.color === "inherit" ? {
      color: undefined
    } : bootstrapColors[x.color === undefined ? "dark" : x.color];
  }

  return {
    root: {
      color: function color(x) {
        return getColor(x).color;
      },
      "& a": {
        color: function color(x) {
          return getColor(x).color;
        },
        fontWeight: "bolder",
        textDecoration: "none",
        "&:hover": {
          textDecoration: "underline"
        }
      }
    }
  };
});
var Typography = /*#__PURE__*/React.forwardRef(function BootstrapButton(props, ref) {
  var classes = useStyles(props);

  var otherProps = _objectWithoutPropertiesLoose(props, ["color"]);

  return React.createElement(MUITypography, Object.assign({}, otherProps, {
    classes: classes,
    ref: ref
  }));
});

/**
 * Emulates the bootstrap alert boxes
 */
var useStyles$1 = /*#__PURE__*/makeStyles(function (theme) {
  var _maxWidthXs, _maxWidthSm, _maxWidthMd, _maxWidthLg, _maxWidthXl;

  // @ts-ignore
  var htmlFontSize = theme.typography.htmlFontSize;
  var coef = theme.typography.fontSize / 14;

  var pxToRem = function pxToRem(size) {
    return size / htmlFontSize * coef + "rem";
  };

  var bootstrapColors = {
    primary: {
      color: theme.palette.primary.dark,
      backgroundColor: colorManipulator.fade(colorManipulator.lighten(theme.palette.primary.light, 0.7), 0.8),
      borderColor: colorManipulator.fade(colorManipulator.lighten(theme.palette.primary.light, 0.5), 0.8)
    },
    secondary: {
      color: theme.palette.secondary.dark,
      backgroundColor: colorManipulator.fade(colorManipulator.lighten(theme.palette.secondary.light, 0.7), 0.8),
      borderColor: colorManipulator.fade(colorManipulator.lighten(theme.palette.secondary.light, 0.5), 0.8)
    },
    success: {
      color: "#155724",
      backgroundColor: colorManipulator.fade("#d4edda", 0.8),
      borderColor: colorManipulator.fade("#c3e6cb", 0.8)
    },
    danger: {
      color: "#721c24",
      backgroundColor: colorManipulator.fade("#f8d7da", 0.8),
      borderColor: colorManipulator.fade("#f5c6cb", 0.8)
    },
    warning: {
      color: "#856404",
      backgroundColor: colorManipulator.fade("#fff3cd", 0.8),
      borderColor: colorManipulator.fade("#ffeeba", 0.8)
    },
    info: {
      color: "#0c5460",
      backgroundColor: colorManipulator.fade("#d1ecf1", 0.8),
      borderColor: colorManipulator.fade("#bee5eb", 0.8)
    },
    light: {
      color: theme.palette.text.secondary,
      backgroundColor: theme.palette.background.paper,
      borderColor: colorManipulator.fade(theme.palette.text.secondary, 0.1)
    },
    dark: {
      color: theme.palette.text.primary,
      backgroundColor: colorManipulator.fade(theme.palette.text.primary, 0.25),
      borderColor: colorManipulator.fade(theme.palette.text.primary, 0.2)
    }
  };

  function getColor(x) {
    return bootstrapColors[x.color === undefined ? "danger" : x.color];
  }

  return {
    root: {
      color: function color(x) {
        return getColor(x).color;
      },
      backgroundColor: function backgroundColor(x) {
        return getColor(x).backgroundColor;
      },
      borderColor: function borderColor(x) {
        return getColor(x).borderColor;
      },
      position: "relative",
      border: "1px solid",
      padding: pxToRem(12) + " " + pxToRem(14),
      paddingRight: "" + pxToRem(28),
      borderRadius: pxToRem(4),
      "& a": {
        color: function color(x) {
          return getColor(x).color;
        }
      },
      "& p": {
        margin: 0
      }
    },
    closeIcon: {
      fontSize: pxToRem(18),
      right: 12,
      position: "absolute",
      cursor: "pointer",
      "&:hover": {
        color: "#333"
      }
    },

    /* Styles applied to the root element if `maxWidth="xs"`. */
    maxWidthXs: (_maxWidthXs = {}, _maxWidthXs[theme.breakpoints.up("xs")] = {
      maxWidth: Math.max(theme.breakpoints.values.xs, 444)
    }, _maxWidthXs),

    /* Styles applied to the root element if `maxWidth="sm"`. */
    maxWidthSm: (_maxWidthSm = {}, _maxWidthSm[theme.breakpoints.up("sm")] = {
      maxWidth: theme.breakpoints.values.sm
    }, _maxWidthSm),

    /* Styles applied to the root element if `maxWidth="md"`. */
    maxWidthMd: (_maxWidthMd = {}, _maxWidthMd[theme.breakpoints.up("md")] = {
      maxWidth: theme.breakpoints.values.md
    }, _maxWidthMd),

    /* Styles applied to the root element if `maxWidth="lg"`. */
    maxWidthLg: (_maxWidthLg = {}, _maxWidthLg[theme.breakpoints.up("lg")] = {
      maxWidth: theme.breakpoints.values.lg
    }, _maxWidthLg),

    /* Styles applied to the root element if `maxWidth="xl"`. */
    maxWidthXl: (_maxWidthXl = {}, _maxWidthXl[theme.breakpoints.up("xl")] = {
      maxWidth: theme.breakpoints.values.xl
    }, _maxWidthXl)
  };
});
function Alert(props) {
  var classes = useStyles$1(props);

  var _React$useState = React.useState(true),
      show = _React$useState[0],
      setShow = _React$useState[1];

  React.useEffect(function () {
    if (props.show !== undefined) {
      setShow(props.show);
    }
  }, [props.show]);

  function handleDismiss() {
    setShow(false);

    if (props.onClose !== undefined) {
      props.onClose();
    }
  }

  var maxWidthClass = classes.maxWidthMd;

  switch (props.maxWidth) {
    case "xl":
      maxWidthClass = classes.maxWidthXl;
      break;

    case "lg":
      maxWidthClass = classes.maxWidthLg;
      break;

    case "md":
      maxWidthClass = classes.maxWidthMd;
      break;

    case "sm":
      maxWidthClass = classes.maxWidthSm;
      break;

    case "xs":
      maxWidthClass = classes.maxWidthXs;
      break;
  }

  return React.createElement(Fade, {
    "in": show,
    unmountOnExit: true
  }, React.createElement("div", {
    className: clsx(classes.root, maxWidthClass)
  }, props.dismissible && React.createElement(CloseIcon, {
    onClick: handleDismiss,
    className: classes.closeIcon,
    color: "inherit"
  }), React.createElement(Typography, {
    color: "inherit"
  }, props.children)));
}
var useStylesForHeading = /*#__PURE__*/makeStyles({
  icon: {
    marginRight: 10,
    verticalAlign: -6,
    "& > *:first-child": {
      fontSize: 32
    }
  }
});

function Heading(props) {
  var classes = useStylesForHeading();
  return React.createElement(Typography, {
    color: "inherit",
    variant: "h5",
    component: "h2"
  }, props.icon && React.createElement("span", {
    className: classes.icon
  }, props.icon), props.children);
}

Alert.Heading = Heading;

var bootstrapColors = ['primary', 'secondary', 'success', 'danger', 'warning', 'info', 'light', 'dark'];

var useStyles$2 = /*#__PURE__*/styles.makeStyles(function (theme) {
  var bootstrapColors = {
    primary: {
      contrastText: theme.palette.primary.contrastText,
      main: theme.palette.primary.main
    },
    secondary: {
      contrastText: theme.palette.secondary.contrastText,
      main: theme.palette.secondary.main
    },
    success: {
      contrastText: "#fff",
      main: "#218838"
    },
    danger: {
      contrastText: "#fff",
      main: "#c82333"
    },
    warning: {
      contrastText: "#333",
      main: "#e0a800"
    },
    info: {
      contrastText: "#fff",
      main: "#138496"
    },
    light: {
      contrastText: theme.palette.text.secondary,
      main: theme.palette.background.paper
    },
    dark: {
      contrastText: theme.palette.background.paper,
      main: theme.palette.text.primary
    }
  };

  function getColor(x) {
    return bootstrapColors[x.color === undefined ? "dark" : x.color];
  } // @ts-ignore


  var htmlFontSize = theme.typography.htmlFontSize;
  var coef = theme.typography.fontSize / 14;

  var pxToRem = function pxToRem(size) {
    return size / htmlFontSize * coef + "rem";
  };

  return {
    root: {
      textTransform: "none",
      boxShadow: "none",
      borderRadius: pxToRem(4),
      padding: function padding(x) {
        return pxToRem(x.size === "large" ? 19 : x.size === "medium" ? 15 : 13) + " " + (x.size === "large" ? 19 : x.size === "medium" ? 15 : 13);
      },
      fontSize: function fontSize(x) {
        return pxToRem(x.size === "large" ? 19 : x.size === "medium" ? 15 : 13);
      },
      lineHeight: "1.5",
      "&.Mui-disabled": {
        opacity: 0.3
      },
      "&.MuiButton-contained": {
        color: function color(x) {
          return getColor(x).contrastText;
        },
        backgroundColor: function backgroundColor(x) {
          return getColor(x).main;
        },
        border: function border(x) {
          return "1px solid " + colorManipulator.fade(colorManipulator.darken(getColor(x).main, 0.3), 0.3);
        },
        "&:hover": {
          backgroundColor: function backgroundColor(x) {
            return colorManipulator.darken(getColor(x).main, 0.25);
          }
        }
      },
      "&.MuiButton-outlined,&.MuiButton-text": {
        color: function color(x) {
          return x.color === "light" ? getColor(x).contrastText : getColor(x).main;
        },
        borderColor: function borderColor(x) {
          return x.color === "light" ? colorManipulator.fade(colorManipulator.darken(getColor(x).main, 0.3), 0.3) : getColor(x).main;
        },
        "&:hover": {
          backgroundColor: function backgroundColor(x) {
            return x.color === "light" ? colorManipulator.fade(colorManipulator.lighten(getColor(x).contrastText, 0.2), 0.15) : colorManipulator.fade(colorManipulator.lighten(getColor(x).main, 0.2), 0.15);
          },
          borderColor: function borderColor(x) {
            return x.color === "light" ? colorManipulator.lighten(getColor(x).contrastText, 0.5) : colorManipulator.lighten(getColor(x).main, 0.5);
          },
          color: function color(x) {
            return x.color === "light" ? colorManipulator.lighten(getColor(x).contrastText, 0.3) : colorManipulator.lighten(getColor(x).main, 0.3);
          }
        }
      },
      "&:hover": {
        boxShadow: "none"
      }
    }
  };
});
var Button = /*#__PURE__*/React.forwardRef(function BootstrapButton(props, ref) {
  var classes = useStyles$2(props);

  var otherProps = _objectWithoutPropertiesLoose(props, ["color"]);

  return React.createElement(MUIButton, Object.assign({}, otherProps, {
    classes: classes,
    ref: ref
  }));
});
Button.defaultProps = {
  size: "medium",
  color: "dark"
};

var useStyles$3 = /*#__PURE__*/styles.makeStyles(function (theme) {
  var bootstrapColors = {
    primary: {
      backgroundColor: theme.palette.primary.main,
      color: theme.palette.primary.contrastText
    },
    secondary: {
      backgroundColor: theme.palette.secondary.main,
      color: theme.palette.primary.contrastText
    },
    success: {
      backgroundColor: "#218838",
      color: "#fff"
    },
    danger: {
      backgroundColor: "#c82333",
      color: "#fff"
    },
    warning: {
      backgroundColor: "#e0a800",
      color: "#fff"
    },
    info: {
      backgroundColor: "#138496",
      color: "#fff"
    },
    light: {
      backgroundColor: theme.palette.background["default"],
      color: theme.palette.text.primary
    },
    dark: {
      backgroundColor: colorManipulator.fade(theme.palette.text.primary, 0.7),
      color: theme.palette.background["default"]
    }
  };

  function getColor(x) {
    return bootstrapColors[x.color === undefined ? "light" : x.color];
  }

  return {
    root: {
      backgroundColor: function backgroundColor(x) {
        return getColor(x).backgroundColor;
      },
      color: function color(x) {
        return getColor(x).color;
      },
      "& a": {
        color: function color(x) {
          return getColor(x).backgroundColor;
        },
        fontWeight: "bolder",
        textDecoration: "none",
        "&:hover": {
          textDecoration: "underline"
        }
      }
    }
  };
});
var Card = /*#__PURE__*/React.forwardRef(function BootstrapButton(props, ref) {
  var classes = useStyles$3(props);

  var otherProps = _objectWithoutPropertiesLoose(props, ["color"]);

  return React.createElement(MUICard, Object.assign({}, otherProps, {
    classes: classes,
    ref: ref,
    variant: "outlined"
  }));
});
function CardHeader(props) {
  var classes = styles.makeStyles(function (theme) {
    return {
      root: {
        padding: "10px 14px 10px 14px",
        backgroundColor: colorManipulator.fade("#000", 0.04),
        borderBottom: "1px solid " + theme.palette.divider
      }
    };
  })();
  return React.createElement("div", {
    className: classes.root
  }, React.createElement(Typography, {
    color: "inherit"
  }, props.children));
}
function CardTitle(props) {
  return React.createElement(Typography, {
    color: "inherit",
    variant: "h5",
    component: "h2"
  }, props.children);
}

exports.CardActionArea = CardActionArea;
exports.CardActions = CardActions;
exports.CardContent = CardContent;
exports.CardMedia = CardMedia;
exports.Alert = Alert;
exports.Button = Button;
exports.Card = Card;
exports.CardHeader = CardHeader;
exports.CardTitle = CardTitle;
exports.Typography = Typography;
exports.bootstrapColors = bootstrapColors;
//# sourceMappingURL=material-ui-bootstrap.cjs.development.js.map
